@@ -19,7 +19,12 @@ impl Default for Compression {
     #[cfg(feature = "lz4")]
     #[inline]
     fn default() -> Self {
-        Compression::Lz4
+        // TODO: remove when compression will be implemented.
+        if cfg!(feature = "test-util") {
+            Compression::None
+        } else {
+            Compression::Lz4
+        }
     }
 
     #[cfg(not(feature = "lz4"))]
